
From: john stultz <johnstul@us.ibm.com>

This patch cleans up a commonly repeated set of changes to the NTP state
variables by adding two helper inline functions:

ntp_clear(): Clears the ntp state variables

ntp_synced(): Returns 1 if the system is synced with a time server.

This was compile tested for alpha, arm, i386, x86-64, ppc64, s390, sparc,
sparc64.

Signed-off-by: John Stultz <johnstul@us.ibm.com>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 arch/alpha/kernel/time.c         |    7 ++-----
 arch/arm/kernel/time.c           |    7 ++-----
 arch/arm26/kernel/time.c         |    7 ++-----
 arch/cris/arch-v10/kernel/time.c |    2 +-
 arch/cris/kernel/time.c          |    5 +----
 arch/frv/kernel/time.c           |    7 ++-----
 arch/h8300/kernel/time.c         |    5 +----
 arch/i386/kernel/time.c          |    7 ++-----
 arch/m32r/kernel/time.c          |    7 ++-----
 arch/m68k/kernel/time.c          |    5 +----
 arch/m68knommu/kernel/time.c     |    7 ++-----
 arch/mips/kernel/sysirix.c       |    5 +----
 arch/mips/kernel/time.c          |    7 ++-----
 arch/mips/sgi-ip27/ip27-timer.c  |    2 +-
 arch/parisc/kernel/time.c        |    5 +----
 arch/ppc/kernel/time.c           |    7 ++-----
 arch/ppc64/kernel/time.c         |    7 ++-----
 arch/s390/kernel/time.c          |    5 +----
 arch/sh/kernel/time.c            |    7 ++-----
 arch/sh64/kernel/time.c          |    7 ++-----
 arch/sparc/kernel/pcic.c         |    5 +----
 arch/sparc/kernel/time.c         |    7 ++-----
 arch/sparc64/kernel/time.c       |    2 +-
 arch/v850/kernel/time.c          |    7 ++-----
 arch/x86_64/kernel/time.c        |    7 ++-----
 arch/xtensa/kernel/time.c        |    7 ++-----
 include/linux/timex.h            |   23 +++++++++++++++++++++++
 27 files changed, 65 insertions(+), 111 deletions(-)

diff -puN arch/alpha/kernel/time.c~ntp-ntp-helper-functions arch/alpha/kernel/time.c
--- devel/arch/alpha/kernel/time.c~ntp-ntp-helper-functions	2005-08-30 18:41:58.000000000 -0700
+++ devel-akpm/arch/alpha/kernel/time.c	2005-08-30 18:41:58.000000000 -0700
@@ -149,7 +149,7 @@ irqreturn_t timer_interrupt(int irq, voi
 	 * CMOS clock accordingly every ~11 minutes. Set_rtc_mmss() has to be
 	 * called as close as possible to 500 ms before the new second starts.
 	 */
-	if ((time_status & STA_UNSYNC) == 0
+	if (ntp_synced()
 	    && xtime.tv_sec > state.last_rtc_update + 660
 	    && xtime.tv_nsec >= 500000 - ((unsigned) TICK_SIZE) / 2
 	    && xtime.tv_nsec <= 500000 + ((unsigned) TICK_SIZE) / 2) {
@@ -502,10 +502,7 @@ do_settimeofday(struct timespec *tv)
 	set_normalized_timespec(&xtime, sec, nsec);
 	set_normalized_timespec(&wall_to_monotonic, wtm_sec, wtm_nsec);
 
-	time_adjust = 0;		/* stop active adjtime() */
-	time_status |= STA_UNSYNC;
-	time_maxerror = NTP_PHASE_LIMIT;
-	time_esterror = NTP_PHASE_LIMIT;
+	ntp_clear();
 
 	write_sequnlock_irq(&xtime_lock);
 	clock_was_set();
diff -puN arch/arm26/kernel/time.c~ntp-ntp-helper-functions arch/arm26/kernel/time.c
--- devel/arch/arm26/kernel/time.c~ntp-ntp-helper-functions	2005-08-30 18:41:58.000000000 -0700
+++ devel-akpm/arch/arm26/kernel/time.c	2005-08-30 18:41:58.000000000 -0700
@@ -114,7 +114,7 @@ static unsigned long next_rtc_update;
  */
 static inline void do_set_rtc(void)
 {
-	if (time_status & STA_UNSYNC || set_rtc == NULL)
+	if (!ntp_synced() || set_rtc == NULL)
 		return;
 
 //FIXME - timespec.tv_sec is a time_t not unsigned long
@@ -189,10 +189,7 @@ int do_settimeofday(struct timespec *tv)
 
 	xtime.tv_sec = tv->tv_sec;
 	xtime.tv_nsec = tv->tv_nsec;
-	time_adjust = 0;		/* stop active adjtime() */
-	time_status |= STA_UNSYNC;
-	time_maxerror = NTP_PHASE_LIMIT;
-	time_esterror = NTP_PHASE_LIMIT;
+	ntp_clear();
 	write_sequnlock_irq(&xtime_lock);
 	clock_was_set();
 	return 0;
diff -puN arch/arm/kernel/time.c~ntp-ntp-helper-functions arch/arm/kernel/time.c
--- devel/arch/arm/kernel/time.c~ntp-ntp-helper-functions	2005-08-30 18:41:58.000000000 -0700
+++ devel-akpm/arch/arm/kernel/time.c	2005-08-30 18:41:58.000000000 -0700
@@ -102,7 +102,7 @@ static unsigned long next_rtc_update;
  */
 static inline void do_set_rtc(void)
 {
-	if (time_status & STA_UNSYNC || set_rtc == NULL)
+	if (!ntp_synced() || set_rtc == NULL)
 		return;
 
 	if (next_rtc_update &&
@@ -292,10 +292,7 @@ int do_settimeofday(struct timespec *tv)
 	set_normalized_timespec(&xtime, sec, nsec);
 	set_normalized_timespec(&wall_to_monotonic, wtm_sec, wtm_nsec);
 
-	time_adjust = 0;		/* stop active adjtime() */
-	time_status |= STA_UNSYNC;
-	time_maxerror = NTP_PHASE_LIMIT;
-	time_esterror = NTP_PHASE_LIMIT;
+	ntp_clear();
 	write_sequnlock_irq(&xtime_lock);
 	clock_was_set();
 	return 0;
diff -puN arch/cris/arch-v10/kernel/time.c~ntp-ntp-helper-functions arch/cris/arch-v10/kernel/time.c
--- devel/arch/cris/arch-v10/kernel/time.c~ntp-ntp-helper-functions	2005-08-30 18:41:58.000000000 -0700
+++ devel-akpm/arch/cris/arch-v10/kernel/time.c	2005-08-30 18:41:58.000000000 -0700
@@ -240,7 +240,7 @@ timer_interrupt(int irq, void *dev_id, s
 	 * The division here is not time critical since it will run once in 
 	 * 11 minutes
 	 */
-	if ((time_status & STA_UNSYNC) == 0 &&
+	if (ntp_synced() &&
 	    xtime.tv_sec > last_rtc_update + 660 &&
 	    (xtime.tv_nsec / 1000) >= 500000 - (tick_nsec / 1000) / 2 &&
 	    (xtime.tv_nsec / 1000) <= 500000 + (tick_nsec / 1000) / 2) {
diff -puN arch/cris/kernel/time.c~ntp-ntp-helper-functions arch/cris/kernel/time.c
--- devel/arch/cris/kernel/time.c~ntp-ntp-helper-functions	2005-08-30 18:41:58.000000000 -0700
+++ devel-akpm/arch/cris/kernel/time.c	2005-08-30 18:41:58.000000000 -0700
@@ -114,10 +114,7 @@ int do_settimeofday(struct timespec *tv)
 	set_normalized_timespec(&xtime, sec, nsec);
 	set_normalized_timespec(&wall_to_monotonic, wtm_sec, wtm_nsec);
 
-	time_adjust = 0;		/* stop active adjtime() */
-	time_status |= STA_UNSYNC;
-	time_maxerror = NTP_PHASE_LIMIT;
-	time_esterror = NTP_PHASE_LIMIT;
+	ntp_clear();
 	write_sequnlock_irq(&xtime_lock);
 	clock_was_set();
 	return 0;
diff -puN arch/frv/kernel/time.c~ntp-ntp-helper-functions arch/frv/kernel/time.c
--- devel/arch/frv/kernel/time.c~ntp-ntp-helper-functions	2005-08-30 18:41:58.000000000 -0700
+++ devel-akpm/arch/frv/kernel/time.c	2005-08-30 18:41:58.000000000 -0700
@@ -85,7 +85,7 @@ static irqreturn_t timer_interrupt(int i
 	 * CMOS clock accordingly every ~11 minutes. Set_rtc_mmss() has to be
 	 * called as close as possible to 500 ms before the new second starts.
 	 */
-	if ((time_status & STA_UNSYNC) == 0 &&
+	if (ntp_synced() &&
 	    xtime.tv_sec > last_rtc_update + 660 &&
 	    (xtime.tv_nsec / 1000) >= 500000 - ((unsigned) TICK_SIZE) / 2 &&
 	    (xtime.tv_nsec / 1000) <= 500000 + ((unsigned) TICK_SIZE) / 2
@@ -216,10 +216,7 @@ int do_settimeofday(struct timespec *tv)
 	set_normalized_timespec(&xtime, sec, nsec);
 	set_normalized_timespec(&wall_to_monotonic, wtm_sec, wtm_nsec);
 
-	time_adjust = 0;		/* stop active adjtime() */
-	time_status |= STA_UNSYNC;
-	time_maxerror = NTP_PHASE_LIMIT;
-	time_esterror = NTP_PHASE_LIMIT;
+	ntp_clear();
 	write_sequnlock_irq(&xtime_lock);
 	clock_was_set();
 	return 0;
diff -puN arch/h8300/kernel/time.c~ntp-ntp-helper-functions arch/h8300/kernel/time.c
--- devel/arch/h8300/kernel/time.c~ntp-ntp-helper-functions	2005-08-30 18:41:58.000000000 -0700
+++ devel-akpm/arch/h8300/kernel/time.c	2005-08-30 18:41:58.000000000 -0700
@@ -116,10 +116,7 @@ int do_settimeofday(struct timespec *tv)
 
 	xtime.tv_sec = tv->tv_sec;
 	xtime.tv_nsec = tv->tv_nsec;
-	time_adjust = 0;		/* stop active adjtime() */
-	time_status |= STA_UNSYNC;
-	time_maxerror = NTP_PHASE_LIMIT;
-	time_esterror = NTP_PHASE_LIMIT;
+	ntp_clear();
 	write_sequnlock_irq(&xtime_lock);
 	clock_was_set();
 	return 0;
diff -puN arch/i386/kernel/time.c~ntp-ntp-helper-functions arch/i386/kernel/time.c
--- devel/arch/i386/kernel/time.c~ntp-ntp-helper-functions	2005-08-30 18:41:58.000000000 -0700
+++ devel-akpm/arch/i386/kernel/time.c	2005-08-30 18:41:58.000000000 -0700
@@ -194,10 +194,7 @@ int do_settimeofday(struct timespec *tv)
 	set_normalized_timespec(&xtime, sec, nsec);
 	set_normalized_timespec(&wall_to_monotonic, wtm_sec, wtm_nsec);
 
-	time_adjust = 0;		/* stop active adjtime() */
-	time_status |= STA_UNSYNC;
-	time_maxerror = NTP_PHASE_LIMIT;
-	time_esterror = NTP_PHASE_LIMIT;
+	ntp_clear();
 	write_sequnlock_irq(&xtime_lock);
 	clock_was_set();
 	return 0;
@@ -347,7 +344,7 @@ static void sync_cmos_clock(unsigned lon
 	 * This code is run on a timer.  If the clock is set, that timer
 	 * may not expire at the correct time.  Thus, we adjust...
 	 */
-	if ((time_status & STA_UNSYNC) != 0)
+	if (!ntp_synced())
 		/*
 		 * Not synced, exit, do not restart a timer (if one is
 		 * running, let it run out).
diff -puN arch/m32r/kernel/time.c~ntp-ntp-helper-functions arch/m32r/kernel/time.c
--- devel/arch/m32r/kernel/time.c~ntp-ntp-helper-functions	2005-08-30 18:41:58.000000000 -0700
+++ devel-akpm/arch/m32r/kernel/time.c	2005-08-30 18:41:58.000000000 -0700
@@ -171,10 +171,7 @@ int do_settimeofday(struct timespec *tv)
 	set_normalized_timespec(&xtime, sec, nsec);
 	set_normalized_timespec(&wall_to_monotonic, wtm_sec, wtm_nsec);
 
-	time_adjust = 0;		/* stop active adjtime() */
-	time_status |= STA_UNSYNC;
-	time_maxerror = NTP_PHASE_LIMIT;
-	time_esterror = NTP_PHASE_LIMIT;
+	ntp_clear();
 	write_sequnlock_irq(&xtime_lock);
 	clock_was_set();
 
@@ -221,7 +218,7 @@ irqreturn_t timer_interrupt(int irq, voi
 	 * called as close as possible to 500 ms before the new second starts.
 	 */
 	write_seqlock(&xtime_lock);
-	if ((time_status & STA_UNSYNC) == 0
+	if (ntp_synced()
 		&& xtime.tv_sec > last_rtc_update + 660
 		&& (xtime.tv_nsec / 1000) >= 500000 - ((unsigned)TICK_SIZE) / 2
 		&& (xtime.tv_nsec / 1000) <= 500000 + ((unsigned)TICK_SIZE) / 2)
diff -puN arch/m68k/kernel/time.c~ntp-ntp-helper-functions arch/m68k/kernel/time.c
--- devel/arch/m68k/kernel/time.c~ntp-ntp-helper-functions	2005-08-30 18:41:58.000000000 -0700
+++ devel-akpm/arch/m68k/kernel/time.c	2005-08-30 18:41:58.000000000 -0700
@@ -166,10 +166,7 @@ int do_settimeofday(struct timespec *tv)
 	set_normalized_timespec(&xtime, sec, nsec);
 	set_normalized_timespec(&wall_to_monotonic, wtm_sec, wtm_nsec);
 
-	time_adjust = 0;		/* stop active adjtime() */
-	time_status |= STA_UNSYNC;
-	time_maxerror = NTP_PHASE_LIMIT;
-	time_esterror = NTP_PHASE_LIMIT;
+	ntp_clear();
 	write_sequnlock_irq(&xtime_lock);
 	clock_was_set();
 	return 0;
diff -puN arch/m68knommu/kernel/time.c~ntp-ntp-helper-functions arch/m68knommu/kernel/time.c
--- devel/arch/m68knommu/kernel/time.c~ntp-ntp-helper-functions	2005-08-30 18:41:58.000000000 -0700
+++ devel-akpm/arch/m68knommu/kernel/time.c	2005-08-30 18:41:58.000000000 -0700
@@ -68,7 +68,7 @@ static irqreturn_t timer_interrupt(int i
 	 * CMOS clock accordingly every ~11 minutes. Set_rtc_mmss() has to be
 	 * called as close as possible to 500 ms before the new second starts.
 	 */
-	if ((time_status & STA_UNSYNC) == 0 &&
+	if (ntp_synced() &&
 	    xtime.tv_sec > last_rtc_update + 660 &&
 	    (xtime.tv_nsec / 1000) >= 500000 - ((unsigned) TICK_SIZE) / 2 &&
 	    (xtime.tv_nsec  / 1000) <= 500000 + ((unsigned) TICK_SIZE) / 2) {
@@ -178,10 +178,7 @@ int do_settimeofday(struct timespec *tv)
 	set_normalized_timespec(&xtime, sec, nsec);
 	set_normalized_timespec(&wall_to_monotonic, wtm_sec, wtm_nsec);
 
-	time_adjust = 0;		/* stop active adjtime() */
-	time_status |= STA_UNSYNC;
-	time_maxerror = NTP_PHASE_LIMIT;
-	time_esterror = NTP_PHASE_LIMIT;
+	ntp_clear();
 	write_sequnlock_irq(&xtime_lock);
 	clock_was_set();
 	return 0;
diff -puN arch/mips/kernel/sysirix.c~ntp-ntp-helper-functions arch/mips/kernel/sysirix.c
--- devel/arch/mips/kernel/sysirix.c~ntp-ntp-helper-functions	2005-08-30 18:41:58.000000000 -0700
+++ devel-akpm/arch/mips/kernel/sysirix.c	2005-08-30 18:41:58.000000000 -0700
@@ -632,10 +632,7 @@ asmlinkage int irix_stime(int value)
 	write_seqlock_irq(&xtime_lock);
 	xtime.tv_sec = value;
 	xtime.tv_nsec = 0;
-	time_adjust = 0;			/* stop active adjtime() */
-	time_status |= STA_UNSYNC;
-	time_maxerror = NTP_PHASE_LIMIT;
-	time_esterror = NTP_PHASE_LIMIT;
+	ntp_clear();
 	write_sequnlock_irq(&xtime_lock);
 
 	return 0;
diff -puN arch/mips/kernel/time.c~ntp-ntp-helper-functions arch/mips/kernel/time.c
--- devel/arch/mips/kernel/time.c~ntp-ntp-helper-functions	2005-08-30 18:41:58.000000000 -0700
+++ devel-akpm/arch/mips/kernel/time.c	2005-08-30 18:41:58.000000000 -0700
@@ -223,10 +223,7 @@ int do_settimeofday(struct timespec *tv)
 	set_normalized_timespec(&xtime, sec, nsec);
 	set_normalized_timespec(&wall_to_monotonic, wtm_sec, wtm_nsec);
 
-	time_adjust = 0;			/* stop active adjtime() */
-	time_status |= STA_UNSYNC;
-	time_maxerror = NTP_PHASE_LIMIT;
-	time_esterror = NTP_PHASE_LIMIT;
+	ntp_clear();
 
 	write_sequnlock_irq(&xtime_lock);
 	clock_was_set();
@@ -442,7 +439,7 @@ irqreturn_t timer_interrupt(int irq, voi
 	 * called as close as possible to 500 ms before the new second starts.
 	 */
 	write_seqlock(&xtime_lock);
-	if ((time_status & STA_UNSYNC) == 0 &&
+	if (ntp_synced() &&
 	    xtime.tv_sec > last_rtc_update + 660 &&
 	    (xtime.tv_nsec / 1000) >= 500000 - ((unsigned) TICK_SIZE) / 2 &&
 	    (xtime.tv_nsec / 1000) <= 500000 + ((unsigned) TICK_SIZE) / 2) {
diff -puN arch/mips/sgi-ip27/ip27-timer.c~ntp-ntp-helper-functions arch/mips/sgi-ip27/ip27-timer.c
--- devel/arch/mips/sgi-ip27/ip27-timer.c~ntp-ntp-helper-functions	2005-08-30 18:41:58.000000000 -0700
+++ devel-akpm/arch/mips/sgi-ip27/ip27-timer.c	2005-08-30 18:41:58.000000000 -0700
@@ -118,7 +118,7 @@ again:
 	 * RTC clock accordingly every ~11 minutes. Set_rtc_mmss() has to be
 	 * called as close as possible to when a second starts.
 	 */
-	if ((time_status & STA_UNSYNC) == 0 &&
+	if (ntp_synced() &&
 	    xtime.tv_sec > last_rtc_update + 660 &&
 	    (xtime.tv_nsec / 1000) >= 500000 - ((unsigned) TICK_SIZE) / 2 &&
 	    (xtime.tv_nsec / 1000) <= 500000 + ((unsigned) TICK_SIZE) / 2) {
diff -puN arch/parisc/kernel/time.c~ntp-ntp-helper-functions arch/parisc/kernel/time.c
--- devel/arch/parisc/kernel/time.c~ntp-ntp-helper-functions	2005-08-30 18:41:58.000000000 -0700
+++ devel-akpm/arch/parisc/kernel/time.c	2005-08-30 18:41:58.000000000 -0700
@@ -188,10 +188,7 @@ do_settimeofday (struct timespec *tv)
 		set_normalized_timespec(&xtime, sec, nsec);
 		set_normalized_timespec(&wall_to_monotonic, wtm_sec, wtm_nsec);
 
-		time_adjust = 0;		/* stop active adjtime() */
-		time_status |= STA_UNSYNC;
-		time_maxerror = NTP_PHASE_LIMIT;
-		time_esterror = NTP_PHASE_LIMIT;
+		ntp_clear();
 	}
 	write_sequnlock_irq(&xtime_lock);
 	clock_was_set();
diff -puN arch/ppc64/kernel/time.c~ntp-ntp-helper-functions arch/ppc64/kernel/time.c
--- devel/arch/ppc64/kernel/time.c~ntp-ntp-helper-functions	2005-08-30 18:41:58.000000000 -0700
+++ devel-akpm/arch/ppc64/kernel/time.c	2005-08-30 18:41:58.000000000 -0700
@@ -129,7 +129,7 @@ static __inline__ void timer_check_rtc(v
          * We should have an rtc call that only sets the minutes and
          * seconds like on Intel to avoid problems with non UTC clocks.
          */
-        if ( (time_status & STA_UNSYNC) == 0 &&
+        if (ntp_synced() &&
              xtime.tv_sec - last_rtc_update >= 659 &&
              abs((xtime.tv_nsec/1000) - (1000000-1000000/HZ)) < 500000/HZ &&
              jiffies - wall_jiffies == 1) {
@@ -436,10 +436,7 @@ int do_settimeofday(struct timespec *tv)
 	 */
 	last_rtc_update = new_sec - 658;
 
-	time_adjust = 0;                /* stop active adjtime() */
-	time_status |= STA_UNSYNC;
-	time_maxerror = NTP_PHASE_LIMIT;
-	time_esterror = NTP_PHASE_LIMIT;
+	ntp_clear();
 
 	delta_xsec = mulhdu( (tb_last_stamp-do_gtod.varp->tb_orig_stamp),
 			     do_gtod.varp->tb_to_xs );
diff -puN arch/ppc/kernel/time.c~ntp-ntp-helper-functions arch/ppc/kernel/time.c
--- devel/arch/ppc/kernel/time.c~ntp-ntp-helper-functions	2005-08-30 18:41:58.000000000 -0700
+++ devel-akpm/arch/ppc/kernel/time.c	2005-08-30 18:41:58.000000000 -0700
@@ -169,7 +169,7 @@ void timer_interrupt(struct pt_regs * re
 		 * We should have an rtc call that only sets the minutes and
 		 * seconds like on Intel to avoid problems with non UTC clocks.
 		 */
-		if ( ppc_md.set_rtc_time && (time_status & STA_UNSYNC) == 0 &&
+		if ( ppc_md.set_rtc_time && ntp_synced() &&
 		     xtime.tv_sec - last_rtc_update >= 659 &&
 		     abs((xtime.tv_nsec / 1000) - (1000000-1000000/HZ)) < 500000/HZ &&
 		     jiffies - wall_jiffies == 1) {
@@ -271,10 +271,7 @@ int do_settimeofday(struct timespec *tv)
 	 */
 	last_rtc_update = new_sec - 658;
 
-	time_adjust = 0;                /* stop active adjtime() */
-	time_status |= STA_UNSYNC;
-	time_maxerror = NTP_PHASE_LIMIT;
-	time_esterror = NTP_PHASE_LIMIT;
+	ntp_clear();
 	write_sequnlock_irqrestore(&xtime_lock, flags);
 	clock_was_set();
 	return 0;
diff -puN arch/s390/kernel/time.c~ntp-ntp-helper-functions arch/s390/kernel/time.c
--- devel/arch/s390/kernel/time.c~ntp-ntp-helper-functions	2005-08-30 18:41:58.000000000 -0700
+++ devel-akpm/arch/s390/kernel/time.c	2005-08-30 18:41:58.000000000 -0700
@@ -139,10 +139,7 @@ int do_settimeofday(struct timespec *tv)
 	set_normalized_timespec(&xtime, sec, nsec);
 	set_normalized_timespec(&wall_to_monotonic, wtm_sec, wtm_nsec);
 
-	time_adjust = 0;		/* stop active adjtime() */
-	time_status |= STA_UNSYNC;
-	time_maxerror = NTP_PHASE_LIMIT;
-	time_esterror = NTP_PHASE_LIMIT;
+	ntp_clear();
 	write_sequnlock_irq(&xtime_lock);
 	clock_was_set();
 	return 0;
diff -puN arch/sh64/kernel/time.c~ntp-ntp-helper-functions arch/sh64/kernel/time.c
--- devel/arch/sh64/kernel/time.c~ntp-ntp-helper-functions	2005-08-30 18:41:58.000000000 -0700
+++ devel-akpm/arch/sh64/kernel/time.c	2005-08-30 18:41:58.000000000 -0700
@@ -247,10 +247,7 @@ int do_settimeofday(struct timespec *tv)
 	set_normalized_timespec(&xtime, sec, nsec);
 	set_normalized_timespec(&wall_to_monotonic, wtm_sec, wtm_nsec);
 
-	time_adjust = 0;		/* stop active adjtime() */
-	time_status |= STA_UNSYNC;
-	time_maxerror = NTP_PHASE_LIMIT;
-	time_esterror = NTP_PHASE_LIMIT;
+	ntp_clear();
 	write_sequnlock_irq(&xtime_lock);
 	clock_was_set();
 
@@ -328,7 +325,7 @@ static inline void do_timer_interrupt(in
 	 * RTC clock accordingly every ~11 minutes. Set_rtc_mmss() has to be
 	 * called as close as possible to 500 ms before the new second starts.
 	 */
-	if ((time_status & STA_UNSYNC) == 0 &&
+	if (ntp_synced() &&
 	    xtime.tv_sec > last_rtc_update + 660 &&
 	    (xtime.tv_nsec / 1000) >= 500000 - ((unsigned) TICK_SIZE) / 2 &&
 	    (xtime.tv_nsec / 1000) <= 500000 + ((unsigned) TICK_SIZE) / 2) {
diff -puN arch/sh/kernel/time.c~ntp-ntp-helper-functions arch/sh/kernel/time.c
--- devel/arch/sh/kernel/time.c~ntp-ntp-helper-functions	2005-08-30 18:41:58.000000000 -0700
+++ devel-akpm/arch/sh/kernel/time.c	2005-08-30 18:41:58.000000000 -0700
@@ -215,10 +215,7 @@ int do_settimeofday(struct timespec *tv)
 	set_normalized_timespec(&xtime, sec, nsec);
 	set_normalized_timespec(&wall_to_monotonic, wtm_sec, wtm_nsec);
 
-	time_adjust = 0;		/* stop active adjtime() */
-	time_status |= STA_UNSYNC;
-	time_maxerror = NTP_PHASE_LIMIT;
-	time_esterror = NTP_PHASE_LIMIT;
+	ntp_clear();
 	write_sequnlock_irq(&xtime_lock);
 	clock_was_set();
 
@@ -252,7 +249,7 @@ static inline void do_timer_interrupt(in
 	 * RTC clock accordingly every ~11 minutes. Set_rtc_mmss() has to be
 	 * called as close as possible to 500 ms before the new second starts.
 	 */
-	if ((time_status & STA_UNSYNC) == 0 &&
+	if (ntp_synced() &&
 	    xtime.tv_sec > last_rtc_update + 660 &&
 	    (xtime.tv_nsec / 1000) >= 500000 - ((unsigned) TICK_SIZE) / 2 &&
 	    (xtime.tv_nsec / 1000) <= 500000 + ((unsigned) TICK_SIZE) / 2) {
diff -puN arch/sparc64/kernel/time.c~ntp-ntp-helper-functions arch/sparc64/kernel/time.c
--- devel/arch/sparc64/kernel/time.c~ntp-ntp-helper-functions	2005-08-30 18:41:58.000000000 -0700
+++ devel-akpm/arch/sparc64/kernel/time.c	2005-08-30 18:41:58.000000000 -0700
@@ -449,7 +449,7 @@ static inline void timer_check_rtc(void)
 	static long last_rtc_update;
 
 	/* Determine when to update the Mostek clock. */
-	if ((time_status & STA_UNSYNC) == 0 &&
+	if (ntp_synced() &&
 	    xtime.tv_sec > last_rtc_update + 660 &&
 	    (xtime.tv_nsec / 1000) >= 500000 - ((unsigned) TICK_SIZE) / 2 &&
 	    (xtime.tv_nsec / 1000) <= 500000 + ((unsigned) TICK_SIZE) / 2) {
diff -puN arch/sparc/kernel/pcic.c~ntp-ntp-helper-functions arch/sparc/kernel/pcic.c
--- devel/arch/sparc/kernel/pcic.c~ntp-ntp-helper-functions	2005-08-30 18:41:58.000000000 -0700
+++ devel-akpm/arch/sparc/kernel/pcic.c	2005-08-30 18:41:58.000000000 -0700
@@ -840,10 +840,7 @@ static int pci_do_settimeofday(struct ti
 
 	xtime.tv_sec = tv->tv_sec;
 	xtime.tv_nsec = tv->tv_nsec;
-	time_adjust = 0;		/* stop active adjtime() */
-	time_status |= STA_UNSYNC;
-	time_maxerror = NTP_PHASE_LIMIT;
-	time_esterror = NTP_PHASE_LIMIT;
+	ntp_clear();
 	return 0;
 }
 
diff -puN arch/sparc/kernel/time.c~ntp-ntp-helper-functions arch/sparc/kernel/time.c
--- devel/arch/sparc/kernel/time.c~ntp-ntp-helper-functions	2005-08-30 18:41:58.000000000 -0700
+++ devel-akpm/arch/sparc/kernel/time.c	2005-08-30 18:41:58.000000000 -0700
@@ -139,7 +139,7 @@ irqreturn_t timer_interrupt(int irq, voi
 
 
 	/* Determine when to update the Mostek clock. */
-	if ((time_status & STA_UNSYNC) == 0 &&
+	if (ntp_synced() &&
 	    xtime.tv_sec > last_rtc_update + 660 &&
 	    (xtime.tv_nsec / 1000) >= 500000 - ((unsigned) TICK_SIZE) / 2 &&
 	    (xtime.tv_nsec / 1000) <= 500000 + ((unsigned) TICK_SIZE) / 2) {
@@ -554,10 +554,7 @@ static int sbus_do_settimeofday(struct t
 	set_normalized_timespec(&xtime, sec, nsec);
 	set_normalized_timespec(&wall_to_monotonic, wtm_sec, wtm_nsec);
 
-	time_adjust = 0;		/* stop active adjtime() */
-	time_status |= STA_UNSYNC;
-	time_maxerror = NTP_PHASE_LIMIT;
-	time_esterror = NTP_PHASE_LIMIT;
+	ntp_clear();
 	return 0;
 }
 
diff -puN arch/v850/kernel/time.c~ntp-ntp-helper-functions arch/v850/kernel/time.c
--- devel/arch/v850/kernel/time.c~ntp-ntp-helper-functions	2005-08-30 18:41:58.000000000 -0700
+++ devel-akpm/arch/v850/kernel/time.c	2005-08-30 18:41:58.000000000 -0700
@@ -66,7 +66,7 @@ static irqreturn_t timer_interrupt (int 
 	 * CMOS clock accordingly every ~11 minutes. Set_rtc_mmss() has to be
 	 * called as close as possible to 500 ms before the new second starts.
 	 */
-	if ((time_status & STA_UNSYNC) == 0 &&
+	if (ntp_synced() &&
 	    xtime.tv_sec > last_rtc_update + 660 &&
 	    (xtime.tv_nsec / 1000) >= 500000 - ((unsigned) TICK_SIZE) / 2 &&
 	    (xtime.tv_nsec / 1000) <= 500000 + ((unsigned) TICK_SIZE) / 2) {
@@ -169,10 +169,7 @@ int do_settimeofday(struct timespec *tv)
 	xtime.tv_sec = tv->tv_sec;
 	xtime.tv_nsec = tv->tv_nsec;
 
-	time_adjust = 0;		/* stop active adjtime () */
-	time_status |= STA_UNSYNC;
-	time_maxerror = NTP_PHASE_LIMIT;
-	time_esterror = NTP_PHASE_LIMIT;
+	ntp_clear();
 
 	write_sequnlock_irq (&xtime_lock);
 	clock_was_set();
diff -puN arch/x86_64/kernel/time.c~ntp-ntp-helper-functions arch/x86_64/kernel/time.c
--- devel/arch/x86_64/kernel/time.c~ntp-ntp-helper-functions	2005-08-30 18:41:58.000000000 -0700
+++ devel-akpm/arch/x86_64/kernel/time.c	2005-08-30 18:41:58.000000000 -0700
@@ -181,10 +181,7 @@ int do_settimeofday(struct timespec *tv)
 	set_normalized_timespec(&xtime, sec, nsec);
 	set_normalized_timespec(&wall_to_monotonic, wtm_sec, wtm_nsec);
 
-	time_adjust = 0;		/* stop active adjtime() */
-	time_status |= STA_UNSYNC;
-	time_maxerror = NTP_PHASE_LIMIT;
-	time_esterror = NTP_PHASE_LIMIT;
+	ntp_clear();
 
 	write_sequnlock_irq(&xtime_lock);
 	clock_was_set();
@@ -476,7 +473,7 @@ static irqreturn_t timer_interrupt(int i
  * off) isn't likely to go away much sooner anyway.
  */
 
-	if ((~time_status & STA_UNSYNC) && xtime.tv_sec > rtc_update &&
+	if (ntp_synced() && xtime.tv_sec > rtc_update &&
 		abs(xtime.tv_nsec - 500000000) <= tick_nsec / 2) {
 		set_rtc_mmss(xtime.tv_sec);
 		rtc_update = xtime.tv_sec + 660;
diff -puN arch/xtensa/kernel/time.c~ntp-ntp-helper-functions arch/xtensa/kernel/time.c
--- devel/arch/xtensa/kernel/time.c~ntp-ntp-helper-functions	2005-08-30 18:41:58.000000000 -0700
+++ devel-akpm/arch/xtensa/kernel/time.c	2005-08-30 18:41:58.000000000 -0700
@@ -122,10 +122,7 @@ int do_settimeofday(struct timespec *tv)
 	set_normalized_timespec(&xtime, sec, nsec);
 	set_normalized_timespec(&wall_to_monotonic, wtm_sec, wtm_nsec);
 
-	time_adjust = 0;                /* stop active adjtime() */
-	time_status |= STA_UNSYNC;
-	time_maxerror = NTP_PHASE_LIMIT;
-	time_esterror = NTP_PHASE_LIMIT;
+	ntp_clear();
 	write_sequnlock_irq(&xtime_lock);
 	return 0;
 }
@@ -184,7 +181,7 @@ again:
 		next += CCOUNT_PER_JIFFY;
 		do_timer (regs); /* Linux handler in kernel/timer.c */
 
-		if ((time_status & STA_UNSYNC) == 0 &&
+		if (ntp_synced() &&
 		    xtime.tv_sec - last_rtc_update >= 659 &&
 		    abs((xtime.tv_nsec/1000)-(1000000-1000000/HZ))<5000000/HZ &&
 		    jiffies - wall_jiffies == 1) {
diff -puN include/linux/timex.h~ntp-ntp-helper-functions include/linux/timex.h
--- devel/include/linux/timex.h~ntp-ntp-helper-functions	2005-08-30 18:41:58.000000000 -0700
+++ devel-akpm/include/linux/timex.h	2005-08-30 18:41:58.000000000 -0700
@@ -260,6 +260,29 @@ extern long pps_calcnt;		/* calibration 
 extern long pps_errcnt;		/* calibration errors */
 extern long pps_stbcnt;		/* stability limit exceeded */
 
+/**
+ * ntp_clear - Clears the NTP state variables
+ *
+ * Must be called while holding a write on the xtime_lock
+ */
+static inline void ntp_clear(void)
+{
+	time_adjust = 0;		/* stop active adjtime() */
+	time_status |= STA_UNSYNC;
+	time_maxerror = NTP_PHASE_LIMIT;
+	time_esterror = NTP_PHASE_LIMIT;
+}
+
+/**
+ * ntp_synced - Returns 1 if the NTP status is not UNSYNC
+ *
+ */
+static inline int ntp_synced(void)
+{
+	return !(time_status & STA_UNSYNC);
+}
+
+
 #ifdef CONFIG_TIME_INTERPOLATION
 
 #define TIME_SOURCE_CPU 0
_
